
.. code:: ipython3

    import malaya

.. code:: ipython3

    malaya.num2word.to_cardinal(123456789)




.. parsed-literal::

    'seratus dua puluh tiga juta empat ratus lima puluh enam ribu tujuh ratus lapan puluh sembilan'



.. code:: ipython3

    malaya.num2word.to_cardinal(10)




.. parsed-literal::

    'sepuluh'



.. code:: ipython3

    malaya.num2word.to_cardinal(12)




.. parsed-literal::

    'dua belas'



.. code:: ipython3

    malaya.num2word.to_ordinal(1)




.. parsed-literal::

    'pertama'



.. code:: ipython3

    malaya.num2word.to_cardinal(1)




.. parsed-literal::

    'satu'



.. code:: ipython3

    malaya.num2word.to_ordinal(10)




.. parsed-literal::

    'kesepuluh'



.. code:: ipython3

    malaya.num2word.to_ordinal(12)




.. parsed-literal::

    'kedua belas'



.. code:: ipython3

    malaya.num2word.to_cardinal(-123456789)




.. parsed-literal::

    'negatif seratus dua puluh tiga juta empat ratus lima puluh enam ribu tujuh ratus lapan puluh sembilan'



.. code:: ipython3

    malaya.num2word.to_cardinal(-1234567.89)




.. parsed-literal::

    'negatif satu juta dua ratus tiga puluh empat ribu lima ratus enam puluh tujuh perpuluhan lapan sembilan'



.. code:: ipython3

    malaya.num2word.to_ordinal(11)




.. parsed-literal::

    'kesebelas'


